==> kittycad-0.4.5-py3-none-any.whl: kittycad/models/commit.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

EG = TypeVar("EG", bound="Commit")


@attr.s(auto_attribs=True)
class Commit:
    """Commit holds the Git-commit (SHA1) that a binary was built from, as reported in the version-string of external tools, such as `containerd`, or `runC`."""  # noqa: E501

    expected: Union[Unset, str] = UNSET
    id: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        expected = self.expected
        id = self.id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if expected is not UNSET:
            field_dict["expected"] = expected
        if id is not UNSET:
            field_dict["id"] = id

        return field_dict

    @classmethod
    def from_dict(cls: Type[EG], src_dict: Dict[str, Any]) -> EG:
        d = src_dict.copy()
        expected = d.pop("expected", UNSET)

        id = d.pop("id", UNSET)

        commit = cls(
            expected=expected,
            id=id,
        )

        commit.additional_properties = d
        return commit

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> kittycad-0.4.8-py3-none-any.whl: kittycad/models/commit.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

VR = TypeVar("VR", bound="Commit")


@attr.s(auto_attribs=True)
class Commit:
    """Commit holds the Git-commit (SHA1) that a binary was built from, as reported in the version-string of external tools, such as `containerd`, or `runC`."""  # noqa: E501

    expected: Union[Unset, str] = UNSET
    id: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        expected = self.expected
        id = self.id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if expected is not UNSET:
            field_dict["expected"] = expected
        if id is not UNSET:
            field_dict["id"] = id

        return field_dict

    @classmethod
    def from_dict(cls: Type[VR], src_dict: Dict[str, Any]) -> VR:
        d = src_dict.copy()
        expected = d.pop("expected", UNSET)

        id = d.pop("id", UNSET)

        commit = cls(
            expected=expected,
            id=id,
        )

        commit.additional_properties = d
        return commit

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
